@@ -1,6 +1,9 @@
+import os.path
 from pathlib import Path
 from typing import Callable, Union
 
+import yaml
+
 from toolkit.render.cutter import generate_rendered_files_recursively
 from toolkit.scaffold.project import context
 
@@ -10,6 +13,7 @@ def generate_rendered_project(
     project_path: str = ".",
     generated_path_hook: Callable[[str], str] = None,
     raw_user_input_context: dict = None,
+    factory_user_input_context: dict = None,
     user_input_context_hook: Callable[[dict], dict] = None,
     project_context: dict = None,
     ignored_fields: list = None,
@@ -20,7 +24,16 @@ def generate_rendered_project(
 
     assert len(template_paths) > 0, "No template paths provided."
 
-    user_input_context = context.get_user_input_context(raw_user_input_context)
+    cutter_file = os.path.join(project_path, "cutter.yaml")
+
+    if os.path.exists(cutter_file):
+        user_input_context = yaml.safe_load(open(cutter_file))
+    else:
+        user_input_context = context.get_user_input_context(raw_user_input_context)
+
+    if factory_user_input_context:
+        factory = context.get_user_input_context(factory_user_input_context)
+        user_input_context["factory"] = factory
 
     ignored_items = context.get_ignored_items(project_context, ignored_fields)
 
